# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) 2016-2017 Anaconda, Inc.
#
# May be copied and distributed freely only as part of an Anaconda or
# Miniconda installation.
# -----------------------------------------------------------------------------
"""Default configuration options."""

# yapf: disable

# Local imports
from anaconda_navigator.config.base import SUBFOLDER
from anaconda_navigator.config.user import UserConfig


# yapf: enable

# -----------------------------------------------------------------------------
# --- Defaults
# -----------------------------------------------------------------------------
DEFAULTS = [
    (
        'main',  # General
        {
            'name': 'Anaconda Navigator',
            'first_run': True,
            'hide_quit_dialog': False,
            'hide_running_apps_dialog': False,
            'hide_update_dialog': False,
            'running_apps_to_close': ['anaconda-fusion'],  # Hidden opt
            'show_startup': True,
            'add_default_channels': True,
            # --- Package Manager
            'conda_active_channels': None,
            # --- Anaconda Client Configuration, these values are not needed
            'anaconda_api_url': 'https://api.anaconda.org',
            'ssl_verification': True,
            'ssl_certificate': None,
            # --- Anaconda Project Configuration
            'projects_path': None,
            'active_project_path': None,
            # --- Preferences
            'enable_high_dpi_scaling': True,
            'provide_analytics': True,
            'show_application_environments': True,
        },
    ),
]

# -----------------------------------------------------------------------------
# --- Config instance
# -----------------------------------------------------------------------------
# IMPORTANT NOTES:
# 1. If you want to *change* the default value of a current option, you need to
#    do a MINOR update in config version, e.g. from 1.0.0 to 1.1.0
# 2. If you want to *remove* options that are no longer needed in our codebase,
#    or if you want to *rename* options, then you need to do a MAJOR update in
#    version, e.g. from 1.0.0 to 2.0.0
# 3. You don't need to touch this value if you're just adding a new option
CONF_VERSION = '2.0.0'
CONF = UserConfig(
    'anaconda-navigator',
    defaults=DEFAULTS,
    version=CONF_VERSION,
    subfolder=SUBFOLDER,
    raw_mode=True,
)



# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright 2016 Continuum Analytics, Inc.
#
# May be copied and distributed freely only as part of an Anaconda or
# Miniconda installation.
# -----------------------------------------------------------------------------
"""
Script to download and bundle the latest metadata while the mechanism
is implemented on bith repo and cloud.
"""

# Standard library imports
import bz2
import os
import tempfile

# Third party imports
import requests

HERE_PATH = os.path.dirname(os.path.realpath(__file__))
NAVIGATOR_PATH = os.path.dirname(HERE_PATH)
METADATA_PATH = os.path.join(
    NAVIGATOR_PATH, 'anaconda_navigator', 'static', 'content',
    'metadata.json.bz2'
)


def update_bundled_metadata():
    """Download latest metadata.json file, compress it and budnle it."""
    url = 'https://repo.continuum.io/pkgs/free/metadata.json'
    filepath = METADATA_PATH
    response = requests.get(url, stream=True)
    handle, temppath = tempfile.mkstemp()

    print('Downloading:', url)
    print('File:', filepath)
    print('Status:', response.status_code)

    with open(temppath, 'wb') as handle:
        for chunk in response.iter_content(chunk_size=512):
            if chunk:  # filter out keep-alive new chunks
                handle.write(chunk)

    # Compress it
    compression_level = 9
    with open(temppath, 'rb') as f:
        data = f.read()
        print('Compressing file')
        compressed_contents = bz2.compress(data, compression_level)

    print('Writing compressed file')
    with open(filepath, 'wb') as f:
        f.write(compressed_contents)

    print('Finished!')


if __name__ == '__main__':
    update_bundled_metadata()
